require 'feed_burner'

describe FeedBurner do
  context 'with an api_key of valid type' do
    it 'should be configurable' do
      FeedBurner.configure do |config|
        config.api_key = "abc_123"
      end

      expect(FeedBurner.api_key).to eq 'abc_123'
    end
  end

  context 'with an api_key of invalid type' do
    it 'should raise an argument error' do
      expect {
        FeedBurner.configure do |config|
          config.api_key = {"abc_123" => :hello}
        end
        }.to raise_error ArgumentError
    end
  end

  describe '.feed' do
    let(:params) { {:username => 'ebdrummond', :trip_id => '1', :text_only => true} }

    context 'with invalid input' do
      it 'should raise an argument error without a username' do
        params[:username] = nil
        expect { FeedBurner.feed(params) }.to raise_error ArgumentError
      end

      it 'should raise an argument error with an invalid username type' do
        params[:username] = 1234
        expect { FeedBurner.feed(params) }.to raise_error ArgumentError
      end

      it 'should raise an argument error without a trip_id' do
        params[:trip_id] = nil
        expect { FeedBurner.feed(params) }.to raise_error ArgumentError
      end

      it 'should raise an argument error with an invalid trip_id type' do
        params[:trip_id] = 1234
        expect { FeedBurner.feed(params) }.to raise_error ArgumentError
      end

      it 'does not raise an error without a :text_only flag' do
        params.delete(:text_only)
        expect { FeedBurner.feed(params) }.to_not raise_error ArgumentError
      end
    end

    context 'with valid input' do
      context 'but invalid or missing api_key' do
        let(:bad_auth_response) do
          JSON.parse('{ "errors": [ { "message":"Bad Authentication data","code":215 } ] }')
        end

        it 'receives an bad authentication error' do
          expect(FeedBurner.feed(params)).to eq bad_auth_response
        end
      end

      context 'with a valid api_key' do
        let(:params) { {:username => 'ebdrummond', :trip_id => '1', :text_only => true} }

        context 'to a public trip' do
          it 'returns the feed' do
        end

        context 'to a private trip I have access to' do
          it 'returns the feed'
        end

        context 'to a private trip I do not have access to' do
          it 'raises an error'
        end
      end
    end
  end
end
